/**
 * Copyright (C) 2015 Wasabeef
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

var RE = {};

RE.currentSelection = {
    "startContainer": 0,
    "startOffset": 0,
    "endContainer": 0,
    "endOffset": 0};

RE.clickImgElement=document.getElementById('editor');
RE.isImg=0;

RE.editor = document.getElementById('editor');

document.addEventListener("selectionchange", function() { RE.backuprange(); });

// Initializations
RE.callback = function() {
   /*window.location.href = "re-callback://" + encodeURI(RE.getHtml());*/
    window.location.href = "re-callback://" + encodeURI(RE.getHtml().replace(/\+/g,'&#43;'));
}

RE.setHtml = function(contents) {
     RE.editor.innerHTML = decodeURIComponent(contents.replace(/\+/g, '%20'));
    /*RE.editor.innerHTML = decodeURIComponent(contents);*/
    /*RE.editor.innerHTML = contents;*/
}

RE.getHtml = function() {
    return RE.editor.innerHTML;
}

RE.getText = function() {
    return RE.editor.innerText;
}

RE.setBaseTextColor = function(color) {
    RE.editor.style.color  = color;
}

RE.setBaseFontSize = function(size) {
    RE.editor.style.fontSize = size;
}

RE.setPadding = function(left, top, right, bottom) {
  RE.editor.style.paddingLeft = left;
  RE.editor.style.paddingTop = top;
  RE.editor.style.paddingRight = right;
  RE.editor.style.paddingBottom = bottom;
}

RE.setBackgroundColor = function(color) {
    document.body.style.backgroundColor = color;
}

RE.setBackgroundImage = function(image) {
    RE.editor.style.backgroundImage = image;
}

RE.setWidth = function(size) {
    RE.editor.style.minWidth = size;
}

RE.setHeight = function(size) {
    document.body.style.minHeight = size;
}

RE.setTextAlign = function(align) {
    RE.editor.style.textAlign = align;
}

RE.setVerticalAlign = function(align) {
    RE.editor.style.verticalAlign = align;
}

RE.setPlaceholder = function(placeholder) {
    RE.editor.setAttribute("placeholder", placeholder);
}

RE.undo = function() {
    document.execCommand('undo', false, null);
}

RE.redo = function() {
    document.execCommand('redo', false, null);
}

RE.setBold = function() {
    document.execCommand('bold', false, null);
}

RE.setItalic = function() {
    document.execCommand('italic', false, null);
}

RE.setSubscript = function() {
    document.execCommand('subscript', false, null);
}

RE.setSuperscript = function() {
    document.execCommand('superscript', false, null);
}

RE.setStrikeThrough = function() {
    document.execCommand('strikeThrough', false, null);
}

RE.setUnderline = function() {
    document.execCommand('underline', false, null);
}

RE.setBullets = function() {
    document.execCommand('InsertUnorderedList', false, null);
}

RE.setNumbers = function() {
    document.execCommand('InsertOrderedList', false, null);
}

RE.setTextColor = function(color) {
    RE.restorerange();
    document.execCommand("styleWithCSS", null, true);
    document.execCommand('foreColor', false, color);
    document.execCommand("styleWithCSS", null, false);
}

RE.setTextBackgroundColor = function(color) {
    RE.restorerange();
    document.execCommand("styleWithCSS", null, true);
    document.execCommand('hiliteColor', false, color);
    document.execCommand("styleWithCSS", null, false);
}

RE.setFontSize = function(fontSize){
    document.execCommand("fontSize", false, fontSize);
}

RE.setHeading = function(heading) {
    document.execCommand('formatBlock', false, '<h'+heading+'>');
}

RE.setIndent = function() {
    document.execCommand('indent', false, null);
}

RE.setOutdent = function() {
    document.execCommand('outdent', false, null);
}

RE.setJustifyLeft = function() {
    document.execCommand('justifyLeft', false, null);
}

RE.setJustifyCenter = function() {
    document.execCommand('justifyCenter', false, null);
}

RE.setJustifyRight = function() {
    document.execCommand('justifyRight', false, null);
}

RE.setBlockquote = function() {
    document.execCommand('formatBlock', false, '<blockquote>');
}

RE.insertImage = function(url, alt) {
    var html = '<img src="' + url + '" alt="' + alt + '" />';
    RE.insertHTML(html);
}

RE.insertHTML = function(html) {
    RE.restorerange();
    document.execCommand('insertHTML', false, html);
}

RE.insertLink = function(url, title) {
    RE.restorerange();
    var sel = document.getSelection();
    if (sel.toString().length == 0) {
        document.execCommand("insertHTML",false,"<a href='"+url+"'>"+title+"</a>");
    } else if (sel.rangeCount) {
       var el = document.createElement("a");
       el.setAttribute("href", url);
       el.setAttribute("title", title);

       var range = sel.getRangeAt(0).cloneRange();
       range.surroundContents(el);
       sel.removeAllRanges();
       sel.addRange(range);
   }
    RE.callback();
}

RE.setTodo = function(text) {
    var html = '<input type="checkbox" name="'+ text +'" value="'+ text +'"/> &nbsp;';
    document.execCommand('insertHTML', false, html);
}

RE.prepareInsert = function() {
    RE.backuprange();
}

RE.backuprange = function(){
    var selection = window.getSelection();
    if (selection.rangeCount > 0) {
      var range = selection.getRangeAt(0);
      RE.currentSelection = {
          "startContainer": range.startContainer,
          "startOffset": range.startOffset,
          "endContainer": range.endContainer,
          "endOffset": range.endOffset};
    }
}

RE.restorerange = function(){
    var selection = window.getSelection();
    selection.removeAllRanges();
    var range = document.createRange();
    range.setStart(RE.currentSelection.startContainer, RE.currentSelection.startOffset);
    range.setEnd(RE.currentSelection.endContainer, RE.currentSelection.endOffset);
    selection.addRange(range);
}

RE.enabledEditingItems = function(e) {
    var items = [];
    if (document.queryCommandState('bold')) {
        items.push('bold');
    }
    if (document.queryCommandState('italic')) {
        items.push('italic');
    }
    if (document.queryCommandState('subscript')) {
        items.push('subscript');
    }
    if (document.queryCommandState('superscript')) {
        items.push('superscript');
    }
    if (document.queryCommandState('strikeThrough')) {
        items.push('strikeThrough');
    }
    if (document.queryCommandState('underline')) {
        items.push('underline');
    }
    if (document.queryCommandState('insertOrderedList')) {
        items.push('orderedList');
    }
    if (document.queryCommandState('insertUnorderedList')) {
        items.push('unorderedList');
    }
    if (document.queryCommandState('justifyCenter')) {
        items.push('justifyCenter');
    }
    if (document.queryCommandState('justifyFull')) {
        items.push('justifyFull');
    }
    if (document.queryCommandState('justifyLeft')) {
        items.push('justifyLeft');
    }
    if (document.queryCommandState('justifyRight')) {
        items.push('justifyRight');
    }
    if (document.queryCommandState('insertHorizontalRule')) {
        items.push('horizontalRule');
    }
    var formatBlock = document.queryCommandValue('formatBlock');
    if (formatBlock.length > 0) {
        items.push(formatBlock);
    }

    window.location.href = "re-state://" + encodeURI(items.join(','));
}

RE.focus = function() {
    var range = document.createRange();
    range.selectNodeContents(RE.editor);
    range.collapse(false);
    var selection = window.getSelection();
    selection.removeAllRanges();
    selection.addRange(range);
    RE.editor.focus();
}

RE.blurFocus = function() {
    RE.editor.blur();
}

RE.removeFormat = function() {
    execCommand('removeFormat', false, null);
}
RE.picHeight=function(height,id){
       var selection=window.getSelection();
	   var range=selection.getRangeAt(0);
	   var node=range.commonAncestorContainer;
	   var element=node.parentElement;
	   var nodePre=node.previousSibling;
	   var nodePpp=node.parentNode.previousSibling;
	   var docu=node.ownerDocument;
	   var ee=docu.documentElement;
	   var img=ee.getElementsByTagName("img"); 
	   var length=img.length;
	  
	    
	      /**
	      ee.scrollIntoView();
	      window.scrollTo(0, 5000);
	      RE.prepareInsert();
	      RE.forcus();
	      **/
	    
	    
	      /** 
	        img[length-1].scrollIntoView();
	        console.log('last='+img[length-1].src); 
	        **/
	        
	      
	        var ei=docu.getElementById(id);   
	        
	        /**
	          console.log('node='+node.tagName+' img='+length+' ele='+element.tagName+' ee='+ee.tagName);
	          console.log(' src='+ei.getAttribute('src'));
	          console.log(' height='+ei.scrollHeight+' left='+ei.offsetLeft+' top='+ei.offsetTop);
	         console.log(' scroll top='+ei.scrollTop+' scroll left='+ei.scrollLeft);
	          console.log(' id='+id);
	        **/
	        
	        /**RE.editor.scrollHeight=ei.scrollHeight;
	        ei.offsetLeft
	        ei.offsetTop
	        ei.scrollHeight
	        window.scrollTo(ei.scrollLeft,ei.offsetTop);**/
	        
	        console.log(' id='+RE.editor.scrollHeight+"  offset="+ei.offsetTop);
	         window.scrollImg1.scrollWhileInsert(ei.scrollLeft,ei.offsetTop,height);
	        /**window.scrollImg1.scrollWhileInsert(ei.scrollLeft,RE.editor.scrollHeight,height);**/
	        
	       /** window.location.hash=id;
	         window.location.href='#'+id;
	       **/
	       
	         
	        
	    /**var h=element.scrollBottom;
	    console.log('h='+h);
	    h=h+parseInt(height);
	    window.scrollTo(0, h);
	    console.log('h='+h+' element='+element.tagName+'height='+height); **/
	    
	    
	    
	   
	   
}
 
RE.previousE=function(){
   var selection=window.getSelection();
   var range=selection.getRangeAt(0);
   var node=range.commonAncestorContainer;
   var nodeP=node.previousSibling;
   
    /**var sn1=selection.focusOffset;
    alert("offset="+sn1);
    if(even.currentTarget){
    alert(33);
    }alert("=node="+node.tagName);
    **/
   if(nodeP==null){
       nodeP=node.parentNode.previousSibling;
       if(nodeP==null){
         /**alert("1  node="+node.nodeName+" node:"+node.parentNode);**/
         window.deleteImgSaila.javaDeleteImg("0","0");
         RE.deleteElse();
         RE.callback();
       }else{
       
        if(nodeP.tagName=='IMG'&&selection.focusOffset==0){
        
        /** alert("4 node="+node.nodeName+" nodeP:"+nodeP);**/
        
        /**
        alert(nodeP); 
        alert(nodeP.tagName+"  nodeName:"+nodeP.nodeName+" attribute:"+nodeP.getAttribute("src"));
        **/
        
        window.deleteImgSaila.javaDeleteImg("1",nodeP.getAttribute("src"));
        var nodepp=nodeP.parentNode;
        
        /**
        alert("par:"+nodepp.tagName);
        **/
        
        nodepp.removeChild(nodeP);
        window.deleteImgSaila.javaDeleteImg("0","0");
       RE.prepareInsert();
       RE.callback();
      }else{
        /**alert("5"+" node="+node.nodeName+" nodeParen="+node.parentNode.nodeName+" nodeP:"+nodeP.nodeName+" offset="+selection.focusOffset);**/
         window.deleteImgSaila.javaDeleteImg("0","0");
         RE.deleteElse();
         RE.callback();
      }
       
      }
     
   }else{
     
     if(nodeP.tagName=='IMG'&&selection.focusOffset==0){
       
        /**alert("2"+" nodeP:"+nodeP);**/
        
       /**
        alert(nodeP); 
        alert(nodeP.tagName+"  nodeName:"+nodeP.nodeName+" attribute:"+nodeP.getAttribute("src"));
        **/
        
        window.deleteImgSaila.javaDeleteImg("1",nodeP.getAttribute("src"));
        var nodepp=nodeP.parentNode;
        
        /**
        alert("par:"+nodepp.tagName);
        **/
        
        nodepp.removeChild(nodeP);
        window.deleteImgSaila.javaDeleteImg("0","0");
        RE.prepareInsert();
        RE.callback();
     }else{
       /**alert("3"+" nodeP:"+nodeP.nodeName+" node="+node.nodeName);**/
         window.deleteImgSaila.javaDeleteImg("0","0");
         RE.deleteElse();
         RE.callback();
     }
   }
   /** RE.editor.select();**/
   window.deleteImgSaila.showIt();
  }
  
RE.delImg2=function(){
/**
 alert(66);**/
 window.deleteImgSaila.javaDeleteImg("1",RE.clickImgElement.getAttribute("src"));
 RE.clickImgElement.parentNode.removeChild(RE.clickImgElement);
 window.deleteImgSaila.javaDeleteImg("0","0");
 /** alert(77);**/
 RE.prepareInsert();
 RE.callback();
 window.deleteImgSaila.showIt();
}
  
  
  function setBlUlOlResult(mes){
    window.judgeBlUlOl.setResult(mes);
  }
 
RE.selectBlLi=function(){
  var selection=window.getSelection();
  var range=selection.getRangeAt(0);
  var node=range.commonAncestorContainer;
  var element=node.parentElement;
  var re=0;
  
  if(node.tagName=='LI'||element.tagName=='LI'||element.tagName=='UL'||element.tagName=='OL'||element.tagName=='BLOCKQUOTE'){
    re=1;
    setBlUlOlResult(re);
    return re;
  }
  
  for(var i=0;i<10;i++){
    node=node.parentNode;
    element=node.parentElement;
    if(element.tagName=='HTML'){
      break;
    }
    if(element.tagName=='LI'||element.tagName=='BLOCKQUOTE'){
      re=1;
      break;
    }
  }
   setBlUlOlResult(re);
   return re;
}
RE.selectPosition=function(){
 alert(12);
                        
 var sel1=document.activeElement;
 alert(sel1.tagName)
 var par=sel1.parentNode;
 alert(par.nodeName+":"+par.nodeType+":"+par.tagName)
 
 var se= window.getSelection();
 var range=se.getRangeAt(0);
 
 var node1=range.commonAncestorContainer;
 
 
 var node=se.anchorNode;
 
 var docu=node.ownerDocument;
 var h=docu.documentElement;
 
 
 var p1=node.parentElement;
  alert("p1: "+p1.tagName+" node:"+node.tagName+" nodeType:"+node.nodeType);
  var node2=node.parentNode;
  var p2=node2.parentElement;
   alert("p2:"+p2.tagName+" node2:"+node2.tagName+" nodetype:"+node2.nodeType);
   var node3=node2.parentNode;
  var p3=node3.parentElement;
  alert("p3: "+p3.tagName+" node3:"+node3.nodeName+" nodetype:"+node3.nodeType);
  
 var mmm=node.rootNode;
 
 var ppp1=node1.parentElement;
 
 alert(ppp1.tagName);
 
 if(selection.tagName=='blockquote'){
 alert('alert');
 }

}
RE.deleteElse=function(){
  document.execCommand('delete',false,null);
}
RE.imgSelection=function(x,y){
 var obj=document.elementFromPoint(x,y);
 if(obj.src!=null){
  var range = document.createRange();
    range.setStartAfter(obj);
    range.collapse(true);
    var selection = window.getSelection();
    selection.removeAllRanges();
    selection.addRange(range);
    RE.currentSelection = {
          "startContainer": range.startContainer,
          "startOffset": range.startOffset,
          "endContainer": range.endContainer,
          "endOffset": range.endOffset};
    window.deleteImgSaila.javaDeleteImg("1","justclickimg");
    RE.clickImgElement=obj;
    RE.isImg=1;
 }else{
    window.deleteImgSaila.javaDeleteImg("0","0");
    RE.isImg=0;
 }
}

RE.imgSelection103=function(x,y){
 var obj=document.elementFromPoint(x,y);
 if(obj.src!=null){
   var range = document.createRange();
    range.selectNodeContents(obj);
    var selection = window.getSelection();
    alert( range.startContainer+","+range.startOffset+","+range.endContainer+","+range.endOffset)
    selection.removeAllRanges();
    selection.addRange(range);
    var sel2=window.getSelection();
     if (sel2.rangeCount > 0) {
      var range2 = sel2.getRangeAt(0);
      RE.currentSelection = {
          "startContainer": range2.startContainer,
          "startOffset": range2.startOffset+1,
          "endContainer": range2.endContainer,
          "endOffset": range2.endOffset};
               RE.editor.focus();
    }
 }

}

RE.imgSelection101=function(x,y){
 var obj=document.elementFromPoint(x,y);
 if(obj.src!=null){
   alert(0);
   RE.restorerange();
   var sel=document.getSelection();
   if(sel.rangeCount){ 
     alert(1);
     var range=sel.getRangeAt(0).cloneRange();
     range.surroundContents(obj);
     sel.removeAllRanges();
     sel.addRange(range);
   }
 }

}

RE.imgSelection102=function(x,y){
       var obj=document.elementFromPoint(x,y);
		if(obj.src!=null){ 
		 console.log(obj);
		 alert(0);
     var selection = obj.getSelection();
     alert(1);
     if (selection.rangeCount > 0) {
     alert(2);
      var range = selection.getRangeAt(0);
      RE.currentSelection = {
          "startContainer": range.startContainer,
          "startOffset": range.startOffset,
          "endContainer": range.endContainer,
          "endOffset": range.endOffset};
     }
     selection.removeAllRanges();
     var range = document.createRange();
     range.setStart(RE.currentSelection.startContainer, RE.currentSelection.startOffset);
     range.setEnd(RE.currentSelection.endContainer, RE.currentSelection.endOffset);
     selection.addRange(range);
          }
}
RE.imgSelection8=function(x,y){
       var obj=document.elementFromPoint(x,y);
		if(obj.src!=null){ 
		  var selection = window.getSelection();
          selection.removeAllRanges();
          var range = document.createRange();
          range.setStart(RE.currentSelection.startContainer, RE.currentSelection.startOffset);
          range.setEnd(RE.currentSelection.endContainer, RE.currentSelection.endOffset);
          selection.addRange(range);
          RE.forcus();
          }
}

RE.imgSelection2=function(x,y){
       var obj=document.elementFromPoint(x,y);
		if(obj.src!=null){ 
          obj.focus(); 
          var len = obj.value.length; 
         if (document.selection) { 
           var sel = obj.createTextRange(); 
           sel.moveStart('character',len+1); 
           sel.collapse(); 
           sel.select(); 
          } else if (typeof obj.selectionStart == 'number' && typeof obj.selectionEnd == 'number') { 
            obj.selectionStart = obj.selectionEnd = len+1; 
          
          }			
        }	
}





 RE.imgSelection7= function(x,y){
             var oTxt1=document.elementFromPoint(x,y);
		   if(oTxt1.src!=null){ 
            alert(1);
            var cursurPosition=-1;
            if(oTxt1.selectionStart){//非IE浏览器
              alert(2);
              cursurPosition= oTxt1.selectionStart;
            }else{//IE
              alert(22);
              obj.setSelectionRange(1,1);
                 alert(2212);
                var range = document.selection.createRange();
                  alert(222);
                range.moveStart("character",-oTxt1.value.length);
                  alert(2222);
                cursurPosition=range.text.length;
            }
            alert(cursurPosition);
            if(oTxt1.selectionStart){//非IE浏览器
                oTxt1.selectionStart=cursurPosition;
            }else{//IE
                var range = oTxt1.createTextRange();
                range.move("character",cursurPosition);
                range.select();
            }
           }
        }

  function keyUp(e){
  alert(" 1code=");
  e=e||event||arguments.callee.caller.arguments[0];
  alert("2 code="+e);
  var code=e.which||e.keyCode||e.charCode;
  alert(" code="+code);
 }
 
 
 
 function keyUp2(){
    var v=RE.isImg;
        /**alert("v="+v);**/
        RE.editor.addEventListener("keyup",function(e){
           v=RE.isImg;
          /**alert("v="+v+"  keyUp00="+e.value+  "  e.which="+e.which);**/
          console.log("v="+v+  "  e.which="+e.which);
         if(e.which==8){
          alert("keyUp11="+v);
         if(v==1){
          RE.isImg=0;
          RE.delImg2();
        }else if(v==0){
          RE.previousE();
        }
        e.preventDefault();
         return true;
        }
        });
       
   }
 RE.showCursorInAnswer =function(){
    //  var range=document.createRange();
    //  var selection=window.getSelection();
    //  var content_=document.createTextNode(RE.editor.value);
    //  range.selectNodeContents(content_);
    //  range.collapse(true);
    //  selection.removeAllRanges();
    //  selection.addRange(range);


    // RE.editor.style.cursor="crosshair";
     
    //  console.log( ' inner= '+RE.editor.innerHTML);
    
    RE.editor.focus();
     
 }
 
 
 function showKeyboard2(){
    window.showBoard.showIt();
  }
// Event Listeners
RE.editor.addEventListener("input", RE.callback);
RE.editor.addEventListener("keyup", function(e) {
    var KEY_LEFT = 37, KEY_RIGHT = 39;
    if (e.which == KEY_LEFT || e.which == KEY_RIGHT) {
        RE.enabledEditingItems(e);
    }
    var v=RE.isImg;
    /**console.log("v 111="+v+ "  which="+e.which+" code="+e.keyCode);
   if(e.which==8){
     console.log("v 222="+v+"  which="+e.which);
      if(v==1){
          RE.isImg=0;
          RE.delImg2();
        }else if(v==0){
          RE.previousE();
        }
        
          e.DOM_VK_BACK_SPACE
          e.DOM_VK_DELETE
          e.preventDefault;
          e.stopPropagation;
          e.preventDefault();
      
    }**/
    /**RE.callback();**/
});
RE.editor.addEventListener("click", RE.enabledEditingItems);

/**callback (event){
  if (event.keyCode === event.DOM_VK_BACK_SPACE || event.keyCode === event.DOM_VK_DELETE)
    // do something
  }
}**/

function lazyload(a){
 function i(){
       for(var a=0,b=h;b>a;a++){
           var c=e[a];j(c)&&(k(c),e.splice(a,1),h--,0===h&&m())
               }
          }
 function j(b){
          var c=document.documentElement.scrollTop||window.pageYOffset||document.body.scrollTop;
          if("undefined"==typeof b)
          return!1;
          for(var d=~~b.getAttribute("data-range")||a.lazyRange,e=c+document.documentElement.clientHeight+d,f=0;
             "BODY"!==b.tagName;)
              f+=b.offsetTop,b=b.offsetParent;return e>f
           }
 function k(b){
          a.lazyTime?setTimeout(function(){l(b)},a.lazyTime+~~b.getAttribute("data-time")):l(b)
              }
 function l(a){
          a.src=a.getAttribute("data-src")
          }
 function m(){
          window.removeEventListener?window.removeEventListener("scroll",i,!1):window.detachEvent("onscroll",i)
            }
 var b=a.id?document.getElementById(a.id):document;
          if(null!==b){
             for(var c=b.getElementsByTagName("img"),d=c.length,e=[],f=0;d>f;f++){
                   var g=c[f];null!==g.getAttribute("data-src")&&(j(g)?l(g):e.push(g))
                 }
             var h=e.length;m(),window.addEventListener?window.addEventListener("scroll",i,!1):window.attachEvent("onscroll",i)
           }
 }


